##############################
## Install Packages 
##############################

install_all <- function(packages) {
  installed_pkgs <- installed.packages()[, "Package"]
  for (pkg in packages) {
    if (!pkg %in% installed_pkgs) {
      install.packages(pkg)
    }
  }
}

# Packages to be installed
packages <- c("tidyr", "dplyr", "haven", "ggplot2", "paneltools", "estimatr", 
"modelsummary", "fect", "fixest", "kableExtra", "rdrobust", "panelView")

install_all(packages)

df <- read_dta("XuYao2015.dta")



##############################
## Summary Statistics
##############################

# Village-Year Observations
vars1 <- c("inv", "loginv", "log_levies", "logpopl", "logincome", "logasset", 
"hhsize","landpc", "logmigration", "logtax", "logtransfer", "share_admin", 
"postcont", "postopen", "secret_ballot", "proxy_voting", "moving_ballot")

datasummary_skim(df %>% select(all_of(vars1)))

# Village Chairperson (by Term)
df_elecyr <- df %>% filter(elecyr == 1)
vars2 <- c("vcfirst", "vcsecond", "vcfirst2", grep("^vc_char_", names(df), value = TRUE),
"vote", "psfirst2", "vcps_clan", "vcps_person", "vc_pb")

datasummary_skim(df_elecyr %>% select(all_of(vars2)))

# Sample village (as of 2005)
df_2005 <- df %>% filter(year == 2005)
vars3 <- c("clan_num", grep("^clansz", names(df), value = TRUE), 
"largeclan", "family_tree", "ances_hall")

datasummary_skim(df_2005 %>% select(all_of(vars3)))


##############################
## Figure Replication
##############################

# Figure 1(a)
plot(density(df$clansz1,na.rm=T,bw=0.04),ylim=c(0,8),
  xlab="",ylab="",main="Population of Clans")
mtext("Density", side=2,line=2)
mtext("Population Share", side=1,line=2)
lines(density(df$clansz2,na.rm=T,bw=0.04),lty=5)
lines(density(df$clansz3,na.rm=T,bw=0.04),lty=2)
lines(density(df$clansz4,na.rm=T,bw=0.04),lty=3,lwd=2)
legend("topright", c("Largest", "2nd-largest","3rd-largest", "4th-largest"), 
       lty = c(1,5,2,3), col=1, lwd=c(1,1,1,2), merge = TRUE, cex=1.5,bty="n")  


# Figure 1(b)
df_clans <- df %>%
  filter(!is.na(year) & !is.na(elecyr)) %>%
  group_by(year) %>%
  summarize(
    largest_clan = sum(vcfirst, na.rm = TRUE),
    second_largest_clan = sum(vcsecond, na.rm = TRUE)
  ) %>%
  ungroup()

## Create a frequency table for total observations by year
freq_table <- table(df$year)
years <- as.numeric(names(freq_table))
freq  <- as.numeric(freq_table)
num_villages_with_elec_vc <- data.frame(year = years, freq = freq)

## Merge clan data with total observations
figure1b <- left_join(df_clans, num_villages_with_elec_vc, by = "year") %>%
  mutate(
    largest_prop = largest_clan / freq,
    second_largest_prop = second_largest_clan / freq
  )

## Plot using dual y-axes
max_freq <- max(figure1b$freq, na.rm = TRUE)
ggplot(figure1b, aes(x = year)) +
  # Left axis: total observations (bars)
  geom_bar(aes(y = freq), stat = "identity", fill = "gray", alpha = 0.5) +
  # Right axis: clan proportions, rescaled to match the bar heights
  geom_line(aes(y = largest_prop * max_freq, color = "Largest Clan"), size = 1) +
  geom_line(aes(y = second_largest_prop * max_freq, color = "Second Largest Clan"), 
            size = 1, linetype = "dashed") +
  scale_y_continuous(
    name = "Number of Villages with Elected VCs",
    limits = c(0, max_freq),
    sec.axis = sec_axis(~ . / max_freq * 100, name = "Percentage %")
  ) +
  scale_color_manual(
    name = "Legend",
    values = c("Largest Clan" = "black", "Second Largest Clan" = "black")
  ) +
  labs(
    x = "Year",
    title = "Number of Elected VCs and Clan Percentages"
  ) +
  theme_minimal()


##############################
## Regression Table Replication
##############################


# Table 2
## Treatment Status 
# Model 1
model1 <- feols(loginv ~ vcfirst + vcsecond, data = df, cluster = ~vill_id)

# Model 2
model2 <- feols(loginv ~ vcfirst + vcsecond | vill_id + year, 
                data = df, cluster = ~vill_id)

# Model 3
model3 <- feols(loginv ~ vcfirst + vcsecond + factor(prov_id):year | vill_id + year , 
                data = df, cluster = ~vill_id)

# Model 4
model4 <- feols(loginv ~ vcfirst + vcsecond + factor(vill_id):year| vill_id + year, 
                data = df, cluster = ~vill_id)

# Model 5
model5 <- feols(loginv ~ vcfirst + vcsecond + hhsize + landpc + logpopl + 
                  logincome + logasset + factor(prov_id):year| + vill_id + year, data = df, cluster = ~vill_id)

# Model 6
model6 <- feols(loginv ~ vcfirst + vcsecond + hhsize + landpc + logpopl + 
                  logincome + logasset + logmigration + logtax + logtransfer + 
                  factor(prov_id):year| vill_id + year, data = df, cluster = ~vill_id)

models_table2 <- list(
  "(1)" = model1,
  "(2)" = model2,
  "(3)" = model3,
  "(4)" = model4,
  "(5)" = model5,
  "(6)" = model6
)

modelsummary(
  models_table2,
  fmt = 3,
  stars = TRUE,
  coef_map = c(
    "vcfirst"  = "VC of the largest clan",
    "vcsecond" = "VC of the second-largest clan"
  ),
  # Omit all other terms you do not want in the main coefficient block:
  coef_omit = "Intercept|vill_id|year|prov_id|hhsize|landpc|logpopl|logincome|logasset|logmigration|logtax|logtransfer",
  # Omit unneeded goodness-of-fit stats:
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  add_rows = tribble(
    ~term,                 ~`(1)`, ~`(2)`, ~`(3)`, ~`(4)`, ~`(5)`, ~`(6)`,
    "Prov. linear trends", "",     "",     "x",    "",     "x",    "x",
    "NFS controls",        "",     "",     "",     "",     "x",    "x",
    "Migrants out",        "",     "",     "",     "",     "",     "x",
    "Taxes (upper-level)", "",     "",     "",     "",     "",     "x",
    "Transfers (upper)",   "",     "",     "",     "",     "",     "x",
  ),
  output = "html"
)

## TWFE Even Study Plot
data_cohort <- get.cohort(data=df, index =c("vill_id","year"), D = "vcfirst2", start0 = TRUE)
df.twfe <- data_cohort
df.twfe[which(is.na(df.twfe$Time_to_Treatment)),'Time_to_Treatment'] <- 0
twfe.est <- feols(loginv ~ i(Time_to_Treatment, vcfirst2 + hhsize + landpc + logpopl + logincome + logasset +logmigration + logtax + logtransfer, ref = -1)| vill_id +year, data = df.twfe, cluster = "vill_id")
twfe.output <- as.matrix(twfe.est$coeftable)

twfe.output <- as.data.frame(twfe.output)
twfe.output$Time <- c(c(-12:-2),c(0:18))+1 
p.twfe <- esplot(twfe.output,Period = 'Time',Estimate = 'Estimate', SE = 'Std. Error', xlim = c(-12,10))
p.twfe


## FEct
fect_out <- fect(loginv ~ vcfirst2 +hhsize + landpc + logpopl + logincome + 
                   logasset +logmigration + logtax + logtransfer, 
                 index = c("vill_id","year"), method = "fe", force = "two-way",
                 se = TRUE, parallel = TRUE, nboots = 200, data = df)
print(fect_out)
plot(fect_out)


# Table 3
## TWFE 
vars <- grep("^loginv_cat_", names(df.twfe), value = TRUE)

models_feols <- lapply(vars, function(v) {
  feols(
    as.formula(paste0(v, " ~ vcfirst2 | vill_id + year")), 
    data    = df.twfe,
    cluster = "vill_id"
  )
})
names(models_feols) <- c("Schooling", "Road & Sanitation", "Electricity", 
                         "Irrigation", "Forestation", "Others") 

modelsummary(
  setNames(models_feols, c("Schooling", "Road & Sanitation", "Electricity", 
                           "Irrigation", "Forestation", "Others")),
  fmt = 3,
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  stars = TRUE,
  coef_rename = c(
    "vcfirst2" = "VC of the largest clan"
  ),
  title  = "VCs of Large Clans and Village Public Investment: by Project Type",
  output = "default"
)


## FEct 
models_fect <- lapply(vars, function(v) {
  fect( formula = as.formula(paste0(v, " ~ vcfirst2")),
    data    = df, index   = c("vill_id","year"),
    force   = "two-way", method = "fe", se = TRUE, nboots  = 200, parallel=TRUE)
})

names(models_fect) <- c("Schooling", "Road & Sanitation", "Electricity", 
                        "Irrigation", "Forestation", "Others")

fect_results <- do.call(rbind, lapply(seq_along(models_fect), function(i) {
  m <- models_fect[[i]]
  data.frame(
    Outcome  = names(models_fect)[i],
    Estimate = as.numeric(m$est.avg[1]),   # ATT
    CI.low   = as.numeric(m$est.avg[4]),     # Lower CI
    CI.high  = as.numeric(m$est.avg[3])      # Upper CI
  )
}))
kable(fect_results)


extract_feols_info <- function(model, model_name, coef_name = "vcfirst2") {
  cf <- coef(model)[coef_name]
  ci <- confint(model)[coef_name, ]
  data.frame(
    Outcome  = model_name,
    Estimate = as.numeric(cf),
    CI.low   = as.numeric(ci[1]),
    CI.high  = as.numeric(ci[2])
  )
}

twfe_results <- do.call(rbind, lapply(seq_along(models_feols), function(i) {
  extract_feols_info(models_feols[[i]], names(models_feols)[i], "vcfirst2")
}))


twfe_results$Method <- "TWFE"
fect_results$Method <- "FEct"

combined_results <- rbind(twfe_results, fect_results)

combined_results$Outcome <- factor(
  combined_results$Outcome,
  levels = c("Schooling","Road & Sanitation","Electricity",
             "Irrigation","Forestation","Others")
)


ggplot(combined_results, aes(x = Outcome, y = Estimate, color = Method)) +
  geom_point(position = position_dodge(width = 0.5), size = 3) +
  geom_errorbar(
    aes(ymin = CI.low, ymax = CI.high),
    width = 0.2,
    position = position_dodge(width = 0.5)
  ) +
  geom_hline(yintercept = 0, linetype = "dashed") +
  labs(
    title = "ATT Estimates: TWFE vs. FECT",
    x = NULL,
    y = "ATT"
  ) +
  theme_minimal()



# Regression Discontinuity
df_clean <- df %>%
  filter(!is.na(vote), !is.na(loginv)) %>%
  mutate(loginv_demeaned = loginv - mean(loginv, na.rm = TRUE))

rd_out <- rdrobust(y = df_clean$loginv_demeaned, x = df_clean$vote, c = 0.5)
kable(summary(rd_out))

# Figure 6
df2 <- df %>%
  filter(!vote %in% c(0, 1)) %>%
  mutate(
    vote_bin = cut(vote, breaks = seq(0, 1, 0.05), include.lowest = TRUE, right = FALSE),
    vote_bin_mid = (as.numeric(vote_bin) - 1) * 0.05 + 0.025
  )


mod_loginv <- feols(loginv ~ factor(prov_id)*year | vill_id + year, data = df2)
df2 <- df2 %>% mutate(loginv_ad = resid(mod_loginv))

df_avg <- df2 %>%
  group_by(vote_bin_mid) %>%
  summarise(avg_loginv_ad = mean(loginv_ad, na.rm = TRUE))

# Plot: binned averages with lowess curves by vcfirst2 group, with a dashed dark grey line at x = 0.5
ggplot() +
  geom_point(data = df_avg, aes(x = vote_bin_mid, y = avg_loginv_ad)) +
  geom_smooth(data = filter(df2, vcfirst2 == 0), aes(x = vote, y = loginv_ad), 
              method = "loess", se = TRUE, color = "navy") +
  geom_smooth(data = filter(df2, vcfirst2 == 1), aes(x = vote, y = loginv_ad), 
              method = "loess", se = TRUE, color = "red") +
  geom_vline(xintercept = 0.5, linetype = "dashed", color = "darkgrey") +
  scale_y_continuous(breaks = seq(-1.5, 1.5, 0.5)) +
  labs(title = "Robustness Check: A Regression Discontinuity Design",
       x = "Vote",
       y = "Residualized Public Goods Investment") +
  theme_minimal()


# Table 4  
mod1 <- feols(log_levies ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)
mod2 <- feols(log_levies ~ inv| vill_id + year, data = df, cluster = ~vill_id)
mod3 <- feols(log_levies ~ vcfirst2 + inv + vcfirst2:inv| vill_id+year, data = df, cluster = ~vill_id)

models_table4 <- list("Model 1" = mod1, "Model 2" = mod2,"Model 3" = mod3)

modelsummary(
  models_table4,
  fmt = 3,                         # decimal places
  stars = TRUE,                    # significance stars
  coef_rename = c(
    "vcfirst2"     = "VCof large clans",
    "inv"       = "Public Goods Investment",
    "vcfirst2:inv" = "VCof large clans x Public Goods Investment"
  ),
  title   = "VCs of Large Clans and Levies",
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  notes   = "Note: All regressions include village and year fixed effects, 
  with SEs clustered by village."
)


# Table 5
mod1 <- feols(share_admin ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)
mod2 <- feols(log_admin ~ vcfirst2| vill_id + year, data = df, cluster = ~vill_id)

models_table5 <- list("Share of administrative expenditure in total expenditure" = mod1, 
                      "Log administrative expenditure (1,000 yuan)" = mod2)

modelsummary(
  models_table5,
  fmt = 3,             # decimal places
  stars = TRUE,        # significance stars
  coef_rename = c("vcfirst2" = "VC of the largest clan"),
  title = "VCs of Large Clans and Administrative Expenditure",
  gof_omit = "AIC|BIC|RMSE|Within|R2",
  notes = "Note: All regressions include village and year fixed effects, 
  with SEs clustered by village."
)

